"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EntityWithSequence = void 0;
const typeorm_1 = require("typeorm");
class DatabaseTypeNotSupported extends Error {
    constructor() {
        super("Database type is not supported"); // (1)
        this.name = "DatabaseTypeNotSupported"; // (2)
    }
}
class EntityWithSequence {
    async __beforeInsert() {
        const className = this.constructor.name;
        const entities = typeorm_1.getConnection().entityMetadatas;
        for (const entity of entities) {
            if (entity.name === className) {
                for (const col of entity.columns) {
                    const metadata = Reflect.getMetadataKeys(this, col.propertyName);
                    if (metadata.includes('nextVal')) {
                        const sequenceName = Reflect.getMetadata('sequenceName', this, col.propertyName);
                        const columnName = Reflect.getMetadata('column', this, col.propertyName);
                        let query = "";
                        if (typeorm_1.getConnection().options.type == "postgres") {
                            query = `select nextval('${sequenceName}') as id`;
                        }
                        else if (typeorm_1.getConnection().options.type == "oracle") {
                            query = `SELECT ${sequenceName}.NEXTVAL as id FROM DUAL`;
                        }
                        else {
                            throw new DatabaseTypeNotSupported();
                        }
                        const nextVal = await typeorm_1.getManager().query(query);
                        this[columnName] = nextVal[0].id || nextVal[0].ID;
                    }
                }
                break;
            }
        }
    }
}
exports.EntityWithSequence = EntityWithSequence;
//# sourceMappingURL=index.js.map